Python API Documentation
========================

This section contains the Python API documentation for the PolytopeWalk library.

Module: polytopewalk
---------------------

.. automodule:: polytopewalk
   :members:
   :undoc-members:
   :show-inheritance:

Classes
--------

.. autoclass:: polytopewalk.DenseCenter
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.SparseCenter
   :members:
   :undoc-members:

RandomWalk Classes
-------------------

.. autoclass:: polytopewalk.dense.RandomWalk
   :members:
   :undoc-members:

.. autoclass:: polytopewalk.sparse.RandomWalk
   :members:
   :undoc-members:

Functions
---------

.. autofunction:: polytopewalk.denseFullWalkRun
   :members:
   :undoc-members:

.. autofunction:: polytopewalk.sparseFullWalkRun
   :members:
   :undoc-members: